# Scrapifurs

Scrapifurs is a toolset to scrape and curate data using. I use chat GPT API to curate select data
## Features

- **Web Scraping**: Easy-to-use functions to scrape data from various web sources.
- **Data Cleaning**: Leverage the power of the GPT API to clean and organize the scraped data.
- **Customizable**:  configurable for specific use cases and data requirements.

## Installation

Install Scrapifurs using pip:

```bash
pip install Scrapifurs
